@@ -137,7 +137,7 @@ class AbstractCategory(TranslatableSlugMixin, MPTTModel):
                 qs = related.model.objects.filter(categories__in=children)
             # Filter only pages related to categories
             if related.name == u'td_cms:page':
-                qs = qs.filter(status='published').order_by('-last_modified')
+                qs = qs.filter(status='published').order_by('position')
             if len(qs):
                 qss += qs
         return qss
